==> dde-clipboard_6.1.8.tar.xz: BUILD/translations/dde-clipboard_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>ClipboardItem</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="34"/>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="65"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
</context>
<context>
    <name>ClipboardPlugin</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboardplugin.cpp" line="43"/>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
</context>
<context>
    <name>ItemData</name>
    <message>
        <location filename="../itemdata.cpp" line="147"/>
        <source>Picture</source>
        <translation>图片</translation>
    </message>
    <message>
        <location filename="../itemdata.cpp" line="149"/>
        <source>Text</source>
        <translation>文本</translation>
    </message>
    <message>
        <location filename="../itemdata.cpp" line="151"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../itemdata.cpp" line="163"/>
        <source>%1 characters</source>
        <translation>%1个字符</translation>
    </message>
</context>
<context>
    <name>ItemWidget</name>
    <message>
        <location filename="../itemwidget.cpp" line="489"/>
        <source>%1 files (%2...)</source>
        <translation>%2 等%1个文件</translation>
    </message>
    <message>
        <location filename="../itemwidget.cpp" line="540"/>
        <location filename="../itemwidget.cpp" line="662"/>
        <source>(File deleted)</source>
        <translation>（源文件已被删除）</translation>
    </message>
    <message>
        <location filename="../itemwidget.cpp" line="570"/>
        <source>Yesterday</source>
        <translation>昨天</translation>
    </message>
    <message>
        <location filename="../itemwidget.cpp" line="576"/>
        <source>Just now</source>
        <translation>刚刚</translation>
    </message>
    <message>
        <location filename="../itemwidget.cpp" line="578"/>
        <source>1 minute ago</source>
        <translation>1分钟前</translation>
    </message>
    <message>
        <location filename="../itemwidget.cpp" line="580"/>
        <source>%1 minutes ago</source>
        <translation>%1分钟前</translation>
    </message>
    <message>
        <location filename="../itemwidget.cpp" line="582"/>
        <source>1 hour ago</source>
        <translation>1小时前</translation>
    </message>
    <message>
        <location filename="../itemwidget.cpp" line="584"/>
        <source>%1 hours ago</source>
        <translation>%1小时前</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="187"/>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Clear all</source>
        <translation>全部清除</translation>
    </message>
</context>
</TS>

==> dde-clipboard_6.1.14.tar.xz: BUILD/translations/dde-clipboard_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>ClipboardItem</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="34"/>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="65"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
</context>
<context>
    <name>ClipboardPlugin</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboardplugin.cpp" line="43"/>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
</context>
<context>
    <name>ItemData</name>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="128"/>
        <source>Picture</source>
        <translation>图片</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="130"/>
        <source>Text</source>
        <translation>文本</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="132"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="144"/>
        <source>%1 characters</source>
        <translation>%1个字符</translation>
    </message>
</context>
<context>
    <name>ItemWidget</name>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="369"/>
        <source>%1 files (%2...)</source>
        <translation>%2 等%1个文件</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="420"/>
        <location filename="../dde-clipboard/itemwidget.cpp" line="609"/>
        <source>(File deleted)</source>
        <translation>（源文件已被删除）</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="443"/>
        <source>Yesterday</source>
        <translation>昨天</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="449"/>
        <source>Just now</source>
        <translation>刚刚</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="451"/>
        <source>1 minute ago</source>
        <translation>1分钟前</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="453"/>
        <source>%1 minutes ago</source>
        <translation>%1分钟前</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="455"/>
        <source>1 hour ago</source>
        <translation>1小时前</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="457"/>
        <source>%1 hours ago</source>
        <translation>%1小时前</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="208"/>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="211"/>
        <source>Clear all</source>
        <translation>全部清除</translation>
    </message>
</context>
</TS>
